==> imsprog_1.3.2.orig.tar.gz: imsprog-1.3.2/IMSProg_editor/language/chipEditor_it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ezp_chip_editor.ui" line="14"/>
        <source>IMSProg chip database editor</source>
        <translation>Editor Database Chips di IMSProg</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="53"/>
        <source>File</source>
        <translation>File</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="64"/>
        <source>Edit</source>
        <translation>Edita</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="108"/>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="111"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="120"/>
        <source>Exit</source>
        <translation>Uscita</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="123"/>
        <location filename="../ezp_chip_editor.ui" line="216"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="132"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="135"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="144"/>
        <source>Delete lines</source>
        <translation>Cancella linee</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="147"/>
        <source>Delete selected lines</source>
        <translation>Cancella linee selezionate</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="150"/>
        <source>Del</source>
        <translation>Canc</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="159"/>
        <source>Add line</source>
        <translation>Aggiungi linea</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="162"/>
        <source>Add selected lines and duplicate data</source>
        <translation>Aggiungi linee selezionate e duplica i dati</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="165"/>
        <source>Ins</source>
        <translation>Ins</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="174"/>
        <source>Move up</source>
        <translation>Muovi su</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="177"/>
        <source>Move lines up</source>
        <translation>Muovi linee su</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="180"/>
        <source>Ctrl+Up</source>
        <translation>Ctrl+Up</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="189"/>
        <source>Move down</source>
        <translation>Muovi giu</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="192"/>
        <source>Move lines down</source>
        <translation>Muovi linee giu</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="195"/>
        <source>Ctrl+Down</source>
        <translation>Ctrl+Down</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="204"/>
        <source>Export selected lines to CSV file</source>
        <translation>Esporta le linee selezionate in un file CSV</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="213"/>
        <source>Export to CSV</source>
        <translation>Esporta in CSV</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="225"/>
        <source>Import from CSV</source>
        <translation>Importa da CSV</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="228"/>
        <source>, Ctrl+Shift+X</source>
        <translation>, Ctrl+Shift+X</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="44"/>
        <location filename="../ezp_chip_editor.cpp" line="46"/>
        <location filename="../ezp_chip_editor.cpp" line="722"/>
        <location filename="../ezp_chip_editor.cpp" line="743"/>
        <source>Open the file</source>
        <translation>Apri il File</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="49"/>
        <location filename="../ezp_chip_editor.cpp" line="687"/>
        <location filename="../ezp_chip_editor.cpp" line="725"/>
        <location filename="../ezp_chip_editor.cpp" line="746"/>
        <source>Current file: </source>
        <translation>File corrente</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="73"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="74"/>
        <source>Manufacture</source>
        <translation>Fabbricante</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="75"/>
        <source>IC Name</source>
        <translation>Nome IC</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="76"/>
        <source>JEDEC ID</source>
        <translation>JEDEC ID</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="77"/>
        <source>Size</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="78"/>
        <source>Sector 
        size</source>
        <translation>Dimensione 
        settore</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="79"/>
        <source>Type 
        HEX</source>
        <translation>Tipo 
        HEX</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="80"/>
        <source>Algo-
rithm</source>
        <translation>Algo-
ritmo</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="81"/>
        <source>Delay</source>
        <translation>Ritardo</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="82"/>
        <source>4 bits
address</source>
        <translation>Indirizzo 
4 bits</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="83"/>
        <source>Block
size K</source>
        <translation>Dimensione
blocco K</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="84"/>
        <source>EEPROM
pages</source>
        <translation>Pagine
EEPROM</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="85"/>
        <source>VCC</source>
        <translation>VCC</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="518"/>
        <location filename="../ezp_chip_editor.cpp" line="555"/>
        <location filename="../ezp_chip_editor.cpp" line="583"/>
        <location filename="../ezp_chip_editor.cpp" line="622"/>
        <location filename="../ezp_chip_editor.cpp" line="662"/>
        <location filename="../ezp_chip_editor.cpp" line="782"/>
        <location filename="../ezp_chip_editor.cpp" line="814"/>
        <source>Warning</source>
        <translation>Avvertenza</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="518"/>
        <location filename="../ezp_chip_editor.cpp" line="555"/>
        <location filename="../ezp_chip_editor.cpp" line="583"/>
        <location filename="../ezp_chip_editor.cpp" line="622"/>
        <location filename="../ezp_chip_editor.cpp" line="662"/>
        <source>No string selected.</source>
        <translation>Nessuna stringa selezionata.</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="682"/>
        <source>Saving file</source>
        <translation>Salvando</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="684"/>
        <source>Save file</source>
        <translation>Salva file</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="741"/>
        <source>Opening file</source>
        <translation>Aprendo</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="782"/>
        <source>Invalid CSV data file format.</source>
        <translation>Formato dati del file CSV non valido.</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="814"/>
        <source>Invalid CSV header file format.</source>
        <translation>Formato dell 'header del file CSV non valido.</translation>
    </message>
</context>
</TS>

==> imsprog_1.3.9.orig.tar.gz: imsprog-1.3.9/IMSProg_editor/language/chipEditor_it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ezp_chip_editor.ui" line="14"/>
        <source>IMSProg chip database editor</source>
        <translation>Editor del database dei chip di IMSProg</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="53"/>
        <source>File</source>
        <translation>File</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="64"/>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="108"/>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="111"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="120"/>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="123"/>
        <location filename="../ezp_chip_editor.ui" line="216"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="132"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="135"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="144"/>
        <source>Delete lines</source>
        <translation>Cancella linee</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="147"/>
        <source>Delete selected lines</source>
        <translation>Cancella linee selezionate</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="150"/>
        <source>Del</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="159"/>
        <source>Add line</source>
        <translation>Aggiungi linea</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="162"/>
        <source>Add selected lines and duplicate data</source>
        <translation>Aggiungi linee selezionate e duplica i dati</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="165"/>
        <source>Ins</source>
        <translation>Inserisci</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="174"/>
        <source>Move up</source>
        <translation>Sposta su</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="177"/>
        <source>Move lines up</source>
        <translation>Sposta su le linee</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="180"/>
        <source>Ctrl+Up</source>
        <translation>Ctrl+Up</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="189"/>
        <source>Move down</source>
        <translation>Sposta giù</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="192"/>
        <source>Move lines down</source>
        <translation>Sposta giù le linee</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="195"/>
        <source>Ctrl+Down</source>
        <translation>Ctrl+Down</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="204"/>
        <source>Export selected lines to CSV file</source>
        <translation>Esporta le linee selezionate in un file CSV</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="213"/>
        <source>Export to CSV</source>
        <translation>Esporta in CSV</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="225"/>
        <source>Import from CSV</source>
        <translation>Importa da CSV</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.ui" line="228"/>
        <source>, Ctrl+Shift+X</source>
        <translation>, Ctrl+Shift+X</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="51"/>
        <location filename="../ezp_chip_editor.cpp" line="53"/>
        <location filename="../ezp_chip_editor.cpp" line="732"/>
        <location filename="../ezp_chip_editor.cpp" line="753"/>
        <source>Open the file</source>
        <translation>Apri il file</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="56"/>
        <location filename="../ezp_chip_editor.cpp" line="697"/>
        <location filename="../ezp_chip_editor.cpp" line="735"/>
        <location filename="../ezp_chip_editor.cpp" line="756"/>
        <source>Current file: </source>
        <translation>File attuale: </translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="80"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="81"/>
        <source>Manufacture</source>
        <translation>Fabbricante</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="82"/>
        <source>IC Name</source>
        <translation>Nome IC</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="83"/>
        <source>JEDEC ID</source>
        <translation>ID JEDEC</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="84"/>
        <source>Size</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="87"/>
        <source>Algo-
rithm</source>
        <translation>Algo-
ritmo</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="88"/>
        <source>Delay</source>
        <translation>Ritardo</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="85"/>
        <source>Sector
size</source>
        <translation>Dimensione
settore</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="86"/>
        <source>Type
HEX</source>
        <translation>Tipo
HEX</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="89"/>
        <source>4 bit
address</source>
        <translation>Indirizzo
4 bit</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="90"/>
        <source>Block
size K</source>
        <translation>Dimensione
blocco K</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="91"/>
        <source>EEPROM
pages</source>
        <translation>Pagine
EEPROM</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="92"/>
        <source>VCC</source>
        <translation>VCC</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="528"/>
        <location filename="../ezp_chip_editor.cpp" line="565"/>
        <location filename="../ezp_chip_editor.cpp" line="593"/>
        <location filename="../ezp_chip_editor.cpp" line="632"/>
        <location filename="../ezp_chip_editor.cpp" line="672"/>
        <location filename="../ezp_chip_editor.cpp" line="792"/>
        <location filename="../ezp_chip_editor.cpp" line="824"/>
        <source>Warning</source>
        <translation>Avviso</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="528"/>
        <location filename="../ezp_chip_editor.cpp" line="565"/>
        <location filename="../ezp_chip_editor.cpp" line="593"/>
        <location filename="../ezp_chip_editor.cpp" line="632"/>
        <location filename="../ezp_chip_editor.cpp" line="672"/>
        <source>No string selected.</source>
        <translation>Nessuna stringa selezionata.</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="692"/>
        <source>Saving file</source>
        <translation>Salvataggio del file in corso</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="694"/>
        <source>Save file</source>
        <translation>Salva file</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="751"/>
        <source>Opening file</source>
        <translation>Apertura del file in corso</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="792"/>
        <source>Invalid CSV data file format.</source>
        <translation>Formato del file dati CSV non valido.</translation>
    </message>
    <message>
        <location filename="../ezp_chip_editor.cpp" line="824"/>
        <source>Invalid CSV header file format.</source>
        <translation>Formato del file header CSV non valido.</translation>
    </message>
</context>
</TS>
